@@ -26,12 +26,11 @@ __copyright__ = """
 2019-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 """
 
-__version__ = "2.6.1"
-
+__version__ = "2.7.0"
 repo_root = pathlib.Path(__file__).parent
 install_requires = (repo_root / "requirements.txt").read_text(encoding="utf-8").split('\n')
 extras_require = {
 		"dates": ["pytz>=2019.1"],
 		"testing": ["pytest>=6.2.0", "pytest-regressions>=2.0.2"],
-		"all": ["pytest-regressions>=2.0.2", "pytest>=6.2.0", "pytz>=2019.1"]
+		"all": ["pytest>=6.2.0", "pytest-regressions>=2.0.2", "pytz>=2019.1"]
 		}
