@@ -61,12 +61,15 @@ General utility functions.
 #
 
 # stdlib
+import contextlib
 import inspect
 import json
+import re
 import sys
+from io import StringIO
 from math import log10
 from pprint import pformat
-from typing import TYPE_CHECKING, Any, Callable, Dict, Iterable, List, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Any, Callable, Dict, Iterable, Iterator, List, Optional, Pattern, Tuple, Union
 
 # this package
 import domdf_python_tools.words
@@ -74,7 +77,7 @@ from domdf_python_tools.typing import HasHead, String
 
 if TYPE_CHECKING or domdf_python_tools.__docs:  # pragma: no cover
 	# 3rd party
-	from pandas import DataFrame, Series  # type: ignore
+	from pandas import DataFrame, Series
 
 	Series.__module__ = "pandas"
 	DataFrame.__module__ = "pandas"
@@ -98,6 +101,9 @@ __all__ = [
 		"magnitude",
 		"trim_precision",
 		"double_repr_string",
+		"redirect_output",
+		"divide",
+		"redivide",
 		]
 
 #: The current major python version.
@@ -286,8 +292,10 @@ def convert_indents(text: str, tab_width: int = 4, from_: str = '\t', to: str =
 
 class _Etcetera(str):
 
+	__slots__ = ()
+
 	def __new__(cls):
-		return str.__new__(cls, "...")  # type: ignore
+		return str.__new__(cls, "...")
 
 	def __repr__(self) -> str:
 		return str(self)
@@ -393,3 +401,69 @@ def double_repr_string(string: str):
 		return repr(string)
 	else:
 		return json.dumps(string, ensure_ascii=False)
+
+
+@contextlib.contextmanager
+def redirect_output(combine: bool = False) -> Iterator[Tuple[StringIO, StringIO]]:
+	"""
+	Context manager to redirect stdout and stderr to two :class:`io.StringIO` objects.
+
+	These are assigned (as a :class:`tuple`) to the target the :keyword:`as` expression.
+
+	Example:
+
+	.. code-block:: python
+
+		with redirect_output() as (stdout, stderr):
+			...
+
+	.. versionadded:: 2.6.0
+
+	:param combine: If :py:obj:`True` ``stderr`` is combined with ``stdout``.
+	"""  # noqa: D400
+
+	if combine:
+		stdout = stderr = StringIO()
+	else:
+		stdout = StringIO()
+		stderr = StringIO()
+
+	with contextlib.redirect_stdout(stdout), contextlib.redirect_stderr(stderr):
+		yield stdout, stderr
+
+
+def divide(string: str, sep: str) -> Tuple[str, str]:
+	"""
+	Divide a string into two parts, about the given string.
+
+	.. versionadded:: 2.7.0
+
+	:param string:
+	:param sep:
+	"""
+
+	if sep not in string:
+		raise ValueError(f"{sep!r} not in {string!r}")
+
+	parts = string.split(sep, 1)
+	return tuple(parts)  # type: ignore
+
+
+def redivide(string: str, pat: Union[str, Pattern]) -> Tuple[str, str]:
+	"""
+	Divide a string into two parts, splitting on the given regular expression.
+
+	.. versionadded:: 2.7.0
+
+	:param string:
+	:param pat:
+	"""
+
+	if isinstance(pat, str):
+		pat = re.compile(pat)
+
+	if not pat.search(string):
+		raise ValueError(f"{pat!r} has no matches in {string!r}")
+
+	parts = pat.split(string, 1)
+	return tuple(parts)  # type: ignore
